pub trait NoPagination { }Expand description
A trait to indicate that an endpoint requires pagination to yield all results or in other words that the non-pagination API should not be used on it or one might miss some results
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".