pub trait ReturnsJsonResponse { }Expand description
A trait to indicate that an endpoint is expected to return a JSON result
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait ReturnsJsonResponse { }A trait to indicate that an endpoint is expected to return a JSON result
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".