pub trait EndpointParameter<E> {
// Required method
fn into_arc(self) -> Arc<E>;
}Expand description
trait to allow both &E and std::sync::Arc<E> as parameters for endpoints
we can not just use Into because that tries to treat &Endpoint as the value E
and screws up our other trait bounds
if we just used Arc the users would have to change all old call sites
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".