pub trait Pageable {
// Required method
fn response_wrapper_key(&self) -> String;
}Expand description
A trait to indicate that an endpoint is pageable.
Required Methods
Sourcefn response_wrapper_key(&self) -> String
fn response_wrapper_key(&self) -> String
returns the name of the key in the response that contains the list of results
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".